@@ -1,7 +1,7 @@
 from django.conf import settings
 from django.core import checks
 from django.db import models
-from django.utils.encoding import force_text
+from django.utils.encoding import force_str
 from django.utils.translation import gettext_lazy as _
 
 from phonenumber_field import formfields
@@ -19,7 +19,9 @@ class PhoneNumberDescriptor:
     Assigns a phone number object on assignment so you can do::
 
         >>> instance.phone_number = PhoneNumber(...)
-    or
+
+    or,
+
         >>> instance.phone_number = '+414204242'
     """
 
@@ -68,23 +70,31 @@ class PhoneNumberField(models.CharField):
         try:
             validate_region(self.region)
         except ValueError as e:
-            return [checks.Error(force_text(e), obj=self)]
+            return [checks.Error(force_str(e), obj=self)]
         return []
 
     def get_prep_value(self, value):
         """
         Perform preliminary non-db specific value checks and conversions.
         """
-        if value:
-            if not isinstance(value, PhoneNumber):
-                value = to_python(value)
+        if not value:
+            return super().get_prep_value(value)
 
-            if not value.is_valid():
-                raise ValueError("“%s” is not a valid phone number." % value.raw_input)
+        if isinstance(value, PhoneNumber):
+            parsed_value = value
+        else:
+            # Convert the string to a PhoneNumber object.
+            parsed_value = to_python(value)
 
+        if parsed_value.is_valid():
+            # A valid phone number. Normalize it for storage.
             format_string = getattr(settings, "PHONENUMBER_DB_FORMAT", "E164")
             fmt = PhoneNumber.format_map[format_string]
-            value = value.format_as(fmt)
+            value = parsed_value.format_as(fmt)
+        else:
+            # Not a valid phone number. Store the raw string.
+            value = parsed_value.raw_input
+
         return super().get_prep_value(value)
 
     def contribute_to_class(self, cls, name, *args, **kwargs):
