@@ -3,7 +3,7 @@ from django import forms
 from django.core import checks
 from django.db.models import Model
 from django.test import TestCase, override_settings
-from django.utils.encoding import force_text
+from django.utils.encoding import force_str
 from phonenumbers import phonenumberutil
 
 from phonenumber_field import formfields, modelfields
@@ -33,17 +33,20 @@ class PhoneNumberFieldTestCase(TestCase):
 
     def test_str_for_valid_number(self):
         self.assertEqual(
-            str(PhoneNumber.from_string(self.test_number_1)), self.test_number_1,
+            str(PhoneNumber.from_string(self.test_number_1)),
+            self.test_number_1,
         )
 
     def test_str_for_invalid_number(self):
         self.assertEqual(
-            str(to_python("invalid")), "invalid",
+            str(to_python("invalid")),
+            "invalid",
         )
 
     def test_repr_for_invalid_number(self):
         self.assertEqual(
-            repr(to_python("invalid")), "InvalidPhoneNumber(raw_input=invalid)",
+            repr(to_python("invalid")),
+            "InvalidPhoneNumber(raw_input=invalid)",
         )
 
     def test_repr_for_valid_number(self):
@@ -257,7 +260,7 @@ class PhoneNumberFieldTestCase(TestCase):
         )
 
 
-class PhonenumerFieldAppTest(TestCase):
+class PhoneNumberFieldAppTest(TestCase):
     def test_save_field_to_database(self):
         """Basic Field Test"""
         tm = models.TestModel()
@@ -409,7 +412,7 @@ class RegionPhoneNumberFormFieldTest(TestCase):
             formfields.PhoneNumberField(region="invalid")
 
         self.assertTrue(
-            force_text(cm.exception).startswith("“invalid” is not a valid region code.")
+            force_str(cm.exception).startswith("“invalid” is not a valid region code.")
         )
 
     def test_error_message_nationalize_example(self):
@@ -516,3 +519,46 @@ class RegionPhoneNumberModelFieldTest(TestCase):
         )
         self.assertEqual(phonenumbers.parse(ALGERIAN_PHONE_NUMBER), m.phone_number)
         self.assertEqual(ALGERIAN_PHONE_NUMBER, m.phone_number)
+
+
+class PhoneNumberOrdering(TestCase):
+    def test_ordering(self):
+        phone1 = PhoneNumber.from_string("+33600000000")
+        phone2 = PhoneNumber.from_string("+33600000001")
+        self.assertLess(phone1, phone2)
+        # Ordering is total.
+        self.assertGreater(phone2, phone1)
+        self.assertLessEqual(phone1, phone1)
+        self.assertGreaterEqual(phone1, phone1)
+        self.assertEqual(phone1, phone1)
+
+    def test_ordering_with_phonenumbers(self):
+        phone1 = PhoneNumber.from_string("+33600000000")
+        phone2 = phonenumbers.parse("+33600000001")
+        self.assertLess(phone1, phone2)
+
+    def test_ordering_contains_None(self):
+        phone1 = PhoneNumber.from_string("+33600000000")
+        msg = "'<' not supported between instances of 'PhoneNumber' and 'NoneType'"
+        for assertion in [
+            self.assertLess,
+            self.assertLessEqual,
+            self.assertGreater,
+            self.assertGreaterEqual,
+        ]:
+            with self.subTest(assertion):
+                with self.assertRaisesMessage(TypeError, msg):
+                    assertion(phone1, None)
+
+    def test_ordering_with_invalid_value(self):
+        phone1 = PhoneNumber.from_string("+33600000000")
+        invalid = PhoneNumber.from_string("+1000000000")
+        invalid_phonenumbers = phonenumbers.parse("+1000000000")
+        for number in [invalid, invalid_phonenumbers]:
+            with self.subTest(number):
+                for p1, p2 in [[phone1, number], [number, phone1]]:
+                    with self.subTest([p1, p2]):
+                        with self.assertRaisesRegex(
+                            ValueError, r"^Invalid phone number: "
+                        ):
+                            self.assertLess(p1, p2)
